@@ -8,6 +8,9 @@
 "_PACKAGE"
 
 .onLoad = function(libname, pkgname) {
+  # CRAN OMP THREAD LIMIT
+  Sys.setenv("OMP_THREAD_LIMIT" = 2)
+
   # nocov start
   x = utils::getFromNamespace("mlr_reflections", ns = "mlr3")
   x$tuner_properties = "dependencies"
@@ -16,6 +19,7 @@
   x = utils::getFromNamespace("mlr_callbacks", ns = "mlr3misc")
   x$add("mlr3tuning.early_stopping", load_callback_early_stopping)
   x$add("mlr3tuning.backup", load_callback_backup)
+  x$add("mlr3tuning.measures", load_callback_measures)
 
   assign("lg", lgr::get_logger("bbotk"), envir = parent.env(environment()))
   if (Sys.getenv("IN_PKGDOWN") == "true") {
