@@ -230,13 +230,12 @@ test_that("TuningInstanceSingleCrit and empty search space works", {
 
   # xval constant
   instance = tune(
-    method = "random_search",
+    tuner = tnr("random_search", batch_size = 5),
     task = tsk("pima"),
     learner = lrn("classif.rpart"),
     resampling = rsmp("cv", folds = 3),
     measures = msr("classif.ce"),
-    term_evals = 10,
-    batch_size = 5
+    term_evals = 10
   )
 
   expect_data_table(instance$result)
@@ -248,13 +247,12 @@ test_that("TuningInstanceSingleCrit and empty search space works", {
   learner$param_set$values$xval = NULL
 
   instance = tune(
-    method = "random_search",
+    tuner = tnr("random_search", batch_size = 5),
     task = tsk("pima"),
     learner = learner,
     resampling = rsmp("cv", folds = 3),
     measures = msr("classif.ce"),
-    term_evals = 10,
-    batch_size = 5
+    term_evals = 10
   )
 
   expect_data_table(instance$result)
